package com.ruoyi.system.service.impl;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.mapper.AppDownloadMapper;
import com.ruoyi.system.domain.AppDownload;
import com.ruoyi.system.service.IAppDownloadService;

/**
 * app下载地址Service业务层处理
 *
 * @author ruoyi
 * @date 2025-06-20
 */
@Service
public class AppDownloadServiceImpl extends ServiceImpl<BaseMapper<AppDownload>,AppDownload> implements IAppDownloadService
{
    @Autowired
    private AppDownloadMapper appDownloadMapper;

    /**
     * 查询app下载地址
     *
     * @param id app下载地址主键
     * @return app下载地址
     */
    @Override
    public AppDownload selectAppDownloadById(Long id)
    {
        return appDownloadMapper.selectAppDownloadById(id);
    }

    /**
     * 查询app下载地址列表
     *
     * @param appDownload app下载地址
     * @return app下载地址
     */
    @Override
    public List<AppDownload> selectAppDownloadList(AppDownload appDownload)
    {
        return appDownloadMapper.selectAppDownloadList(appDownload);
    }

    /**
     * 新增app下载地址
     *
     * @param appDownload app下载地址
     * @return 结果
     */
    @Override
    public int insertAppDownload(AppDownload appDownload)
    {
        return appDownloadMapper.insertAppDownload(appDownload);
    }

    /**
     * 修改app下载地址
     *
     * @param appDownload app下载地址
     * @return 结果
     */
    @Override
    public int updateAppDownload(AppDownload appDownload)
    {
        return appDownloadMapper.updateAppDownload(appDownload);
    }

    /**
     * 批量删除app下载地址
     *
     * @param ids 需要删除的app下载地址主键
     * @return 结果
     */
    @Override
    public int deleteAppDownloadByIds(Long[] ids)
    {
        return appDownloadMapper.deleteAppDownloadByIds(ids);
    }

    /**
     * 删除app下载地址信息
     *
     * @param id app下载地址主键
     * @return 结果
     */
    @Override
    public int deleteAppDownloadById(Long id)
    {
        return appDownloadMapper.deleteAppDownloadById(id);
    }
}
